==> apache-gobblin-incubating-sources-0.14.0.tgz: apache-gobblin-incubating-sources-0.14.0/gobblin-service/src/main/java/org/apache/gobblin/service/modules/spec/SerializationConstants.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.gobblin.service.modules.spec;

public class SerializationConstants {
  public static final String JOB_SPEC_URI_KEY= "uri";
  public static final String JOB_SPEC_VERSION_KEY = "version";
  public static final String JOB_SPEC_DESCRIPTION_KEY = "description";
  public static final String JOB_SPEC_TEMPLATE_URI_KEY = "templateURI";
  public static final String JOB_SPEC_CONFIG_KEY = "config";
  public static final String JOB_SPEC_KEY = "jobSpec";

  public static final String SPEC_EXECUTOR_CONFIG_KEY = "config";
  public static final String SPEC_EXECUTOR_CLASS_KEY = "class";
  public static final String SPEC_EXECUTOR_KEY = "specExecutor";

  public static final String EXECUTION_STATUS_KEY = "executionStatus";
}

==> apache-gobblin-incubating-sources-0.15.0.tgz: apache-gobblin-incubating-sources-0.15.0/gobblin-service/src/main/java/org/apache/gobblin/service/modules/spec/SerializationConstants.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.gobblin.service.modules.spec;

public class SerializationConstants {
  public static final String JOB_SPEC_URI_KEY= "uri";
  public static final String JOB_SPEC_VERSION_KEY = "version";
  public static final String JOB_SPEC_DESCRIPTION_KEY = "description";
  public static final String JOB_SPEC_TEMPLATE_URI_KEY = "templateURI";
  public static final String JOB_SPEC_CONFIG_KEY = "config";
  public static final String JOB_SPEC_KEY = "jobSpec";

  public static final String SPEC_EXECUTOR_CONFIG_KEY = "config";
  public static final String SPEC_EXECUTOR_CLASS_KEY = "class";
  public static final String SPEC_EXECUTOR_KEY = "specExecutor";
  public static final String SPEC_EXECUTOR_URI_KEY = "uri";

  public static final String EXECUTION_STATUS_KEY = "executionStatus";
  public static final String JOB_EXECUTION_FUTURE = "jobExecutionFuture";
}
